# Copyright 2019 Red Hat
# Copyright 2022 Acme Gating, LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
#
# See the License for the specific language governing permissions and
# limitations under the License.

from nodepool.driver.statemachine import StateMachineDriver
from nodepool.driver.gce.config import GceProviderConfig
from nodepool.driver.gce.adapter import GceAdapter


class GceDriver(StateMachineDriver):
    def getProviderConfig(self, provider):
        return GceProviderConfig(self, provider)

    def getAdapter(self, provider_config):
        return GceAdapter(provider_config)
